#
# spec file for package python-zstd
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-zstd
Version:        1.5.5.1
Release:        1.7
Summary:        ZSTD Bindings for Python
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            https://github.com/sergey-dryabzhinsky/python-zstd
Source:         https://files.pythonhosted.org/packages/source/z/zstd/zstd-%{version}.tar.gz
Patch0:         test-external.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libzstd) >= 1.4.4
%python_subpackages

%description
ZSTD Bindings for Python.

%prep
%autosetup -p1 -n zstd-%{version}

rm -rf zstd/
# do not test the version matching, we don't really need exact version of
# zstd here
rm tests/test_version.py
sed -i -e '/test_version/d' tests/__init__.py

%build
export CFLAGS="%{optflags}"
%python_build --legacy --external

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pytest_arch

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitearch}/zstd*.so
%{python_sitearch}/zstd-%{version}*-info

%changelog
* Wed May  3 2023 Dirk Müller <dmueller@suse.com>
- update to 1.5.5.1:
  * Update bindled libzstd to 1.5.5
  * Fix decompression of multiple concatenated frames in one
    input string
  * Generic automated builds are pushed to PyPi.
  * `x86` and `x64` builded under Ubuntu 16.04. And with sse+sse2
    optimizations enabled via compiler.
  * `armhf` and `arm64` builded under Ubuntu 18.04.
  * `armhf` builded on Raspberry PI 2B and optimized for it.
  * `arm64` builded on Raspberry PI 4B and optimized for it.
  * PyPy builds on `arm64` missing `2.7` as it are broken.
  * MacOsX builds done inside 11.7 hackintosh
  * Don't fail with exception if defined number of threads to
    compress is bigger than libzstd can take.
  * Silently drop it value down to max threads.
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Tue Feb 28 2023 Matej Cepl <mcepl@suse.com>
- Update to version 1.5.4.0:
  - Update libzstd to 1.5.4
* Wed Oct 12 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 1.5.2.6
  * Fix a nasty bug - corrupted compression of empty string, and decompression too.
  * Wheels
    Generic automated builds are pushed to PyPi.
    x86 and x64 builded under Ubuntu 16.04. And with sse+sse2 optimizations enabled via compiler.
    armhf and arm64 builded under Ubuntu 18.04.
    armhf builded on Raspberry PI 2B and optimized for it.
    arm64 builded on Raspberry PI 4B and optimized for it.
    There is no Python-3.10 for armhf yeat.
    PyPy builds on arm64 missing 2.7 and 3.7 as they are broken.
    MacOsX builds done inside 11.6 hackintosh
    There is no builds for Windows.
* Sat Jun  4 2022 Dirk Müller <dmueller@suse.com>
- update to 1.5.2.5:
  * Update bundled libzstd to 1.5.2
  * Add support of setting build options via envvars
  * Fixed config for github actions to build wheels
  * Force disable all ASM for AMD code
* Mon Jan 10 2022 Dirk Müller <dmueller@suse.com>
- update to 1.5.1.0:
  * update libzstd to 1.5.1 - follow upstream
  * fix passing VERSION string to compiler
* Mon Dec  6 2021 Dirk Müller <dmueller@suse.com>
- update to 1.5.0.4:
  * python 3.9/3.10 support
* Mon Jul 19 2021 Dirk Müller <dmueller@suse.com>
- update to 1.5.0.2:
  * simplify tests
  * add new function for them: ZSTD_external(): 0/1
  * fix build - missing new file: zstd_errors.h
  * Removed old function which generated custom block header
  * Updated zstd to new upstream version 1.5.0
- drop test-once.patch: not needed
* Mon Feb  1 2021 Dirk Müller <dmueller@suse.com>
- update to 1.4.8.1:
  * Allow ultra-fast levels from -100 to -1
  * Update bundled zstd library to 1.4.8 release
* Wed Jan 13 2021 pgajdos@suse.com
- use %%pytest_arch macro
* Fri Jul 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.4.5.1:
  * Follows upstream 1.4.5 release
* Tue Jan 21 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 1.4.4.0
  * Follow upstream 1.4.4
* Mon Sep  9 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.4.3.2:
  * Follow upstream 1.4.3
* Tue Aug 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Skip the version comparison tests, they are pretty useless
* Mon Jul 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.4.1.0:
  * Follow upstream 1.4.1
* Mon May  6 2019 pgajdos@suse.com
- version update to 1.4.0.0
  * Add LICENSE to MANIFEST.in
  * Fix version tests - don't sort, just reverse
  * Remove debug logging
* Mon Mar  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Switch to pkgconfig style dependency
* Mon Mar  4 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.3.8.1, adding test-external.patch to allow
  tests to run with an external library, and test-once.patch to avoid
  custom hack to run tests which actually runs them twice.
